;;; GraphCube --- The Graph utility cubes for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2024 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://devheroes.codes/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;; Cubes are the building blocks of any `FG42' editor.  Each `cube' is a
;; unit which defines different abilities in a deterministic and idempotent
;; way.  Cubes are composable and a composition of cubes creates an editor.
;;
;;; Code:
(require 'fpkg)
(require 'fg42/cube)


(defcube fg42/graphviz-cube
  "This cube enable =dot= file editing in *FG42*. Using this cube you should
be able to edit =dot= files and use =C-c C-p= to see a preview of your =dot=
file. Use =C-c C-c= to compile the =dot= file.

If =company= flag is enabled then =dot= autocomplete will be enabled as well."
  :title "Graphviz Cube"
  :flag graphviz
  :flag-default t
  :modes 'graphviz-dot-mode

  (let ((indent-size (or (plist-get fg42/graphviz-cube-params :indent-size) 4)))
    (fg42/after-cubes
      (when-flag org
        (add-hook 'org-mode-hook
                  (lambda ()
                    (org-babel-do-load-languages
                     'org-babel-load-languages
                     '((dot . t)
                       (graphviz-dot . t)))))))

    (fpkg/use graphviz-dot-mode
      :config
      (setq graphviz-dot-indent-width indent-size))))


(provide 'fg42/cubes/graph)
;;; graph.el ends here
