;;; LangToolCube --- A language tool cube for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2024 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://devheroes.codes/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;; Cubes are the building blocks of any `FG42' editor.  Each `cube' is a
;; unit which defines different abilities in a deterministic and idempotent
;; way.  Cubes are composable and a composition of cubes creates an editor.
;;
;;; Code:
(require 'fpkg)
(require 'fg42/cube)

(defcube fg42/langtool-cube
  "A Language Server for LanguageTool with support for LaTeX, Markdown,
 and others. For more info checkout [[https://github.com/emacs-languagetool/lsp-ltex]]"
  :title "Language tool Cube"
  :flag language-tool
  :flag-default t

  (let ((user (plist-get fg42/langtool-cube-params :username))
        (apikey (plist-get fg42/langtool-cube-params :api-key)))
    (fpkg/use lsp-ltex
      :hook (text-mode . (lambda ()
                           (require 'lsp-ltex)
                           (lsp)))  ; or lsp-deferred
      :init
      (setq lsp-ltex-version "15.2.0")
      (when user
        (setq lsp-ltex-languagetool-http-server-uri "https://api.languagetoolplus.com/")
        (setq lsp-ltex-languagetool-org-username user)
        (setq lsp-ltex-languagetool-org-api-key apikey)))))

(provide 'fg42/cubes/langtool)
;;; langtool.el ends here
