;;; SchemeCube --- Scheme support cube for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2024 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://devheroes.codes/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;; Cubes are the building blocks of any `FG42' editor.  Each `cube' is a
;; unit which defines different abilities in a deterministic and idempotent
;; way.  Cubes are composable and a composition of cubes creates an editor.
;;
;;; Code:
(require 'fpkg)
(require 'fg42/cube)


(defcube fg42/guile-cube
  "This cube adds supports for GNU Guile Scheme via =emacs-lsp-scheme= library.
For more info checkout [[https://codeberg.org/rgherdt/emacs-lsp-scheme]]"
  :title "Scheme Cube"
  :flag scheme
  :flag-default t

  (fg42/rainbow-delimiters-cube)
  (fg42/paredit-cube)

  (fpkg/use lsp-scheme
    :hook (scheme-mode . lsp-scheme-guile)
    :config
    (add-hook 'scheme-mode-hook #'lsp-scheme)
    (setq lsp-scheme-implementation "guile")))


(provide 'fg42/cubes/scheme)
;;; scheme.el ends here
