;;; Themes --- The common cubes for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2024 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://devheroes.codes/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;;; Code:
(require 'fpkg)
(require 'fg42/cube)
(require 'fg42/utils)
(require 'fg42/themes)


(defcube fg42/dracula-theme-cube
  "Replace this with a theme cube"
  :title "Dracula theme"
  :flag dracula-theme
  :flag-default t
  :ui-hook (lambda ()
             (fpkg/use dracula-theme
               :init
               (fg42/setup-theme
                (require 'dracula-theme)
                (load-theme 'dracula t)
                (custom-theme-set-faces
                 'dracula
                 '(match ((t (:background "#44475a"))))
                 '(all-the-icons-lgreen ((t (:background "#bd93f9"))))
                 '(all-the-icons-faicon ((t (:background "#bd93f9"))))
                 '(font-lock-comment-face ((t (:foreground "#8B9298"))))
                 ;; This fixes lsp-ui-sideline issue
                 '(lsp-ui-sideline-current-symbol ((t (:line-width -1 :foreground "#bd93f9"))))
                 '(font-lock-comment-delimiter-face ((t (:foreground "#5B6268")))))
                (enable-theme 'dracula)
                (set-face-attribute 'region nil :background "#888")))))


(defcube fg42/badwolf-theme-cube
  "Badwolf theme cube. An Emacs port of Bad Wolf theme for Vim.
https://emacsthemes.com/themes/badwolf-theme.html"
  :title "Badwolf theme"
  :flag badwolf-theme
  :flag-default nil
  :ui-hook (lambda ()
             (fpkg/use badwolf-theme
               :init
               (fg42/setup-theme
                (load-theme 'badwolf t)
                (custom-theme-set-faces
                 'badwolf)
                (enable-theme 'badwolf)))))


(provide 'fg42/cubes/themes)
;;; themes.el ends here
